5.1. Setuplib Commands — setupjavax documentation

# 5.1. Setuplib Commands

## 5.1.1. Java Build Commands

### 5.1.1.1. build_java

The build_java command extension supports the build of Java modules within the Python distribution tree. Therefore the provided package directories are scanned for *.java files, which are compiled and copied into the build subtree. These are than included into the distribution transparently by the choosen packer.

> CLI command | build_java
> API class | setuplib.build_java.BuildJava

### 5.1.1.2. build_jy

The command build_jy combines the standard command build_py with the extension command build_java and generates the build tree for both by one call.

> CLI command | build_jy
> API class | setuplib.build_jy.BuildJy